require 'minitest/autorun'
require File.join(__FILE__, '../../lib/spinner')

class SpinnerTest < Minitest::Test

  GLOBAL = []

  def setup
    STDOUT.puts("\n")
    @spinner = Spinner.new
  end

  def test_adding_block_tasks
    @spinner.task { sleep(0.1) }
    assert @spinner.queue.size == 1
    assert @spinner.queue.first[1].respond_to?(:call)
  end

  def test_adding_rake_tasks
    @spinner.task(nil, "test")
    assert @spinner.queue.size == 1
    assert Rake::Task.tasks.include?(@spinner.queue.first[1])
    Rake::Task.clear
  end

  def test_adding_initial_tasks
    tasks = []
    tasks << [ "One", lambda { sleep(0.1) } ]
    spinner = Spinner.new(*tasks)
    assert spinner.queue.first[0] == "One"
  end

  def test_executing_tasks
    @spinner.task { GLOBAL << '1' }
    @spinner.task { GLOBAL << '2' }
    @spinner.task { GLOBAL << '3' }
    @spinner.spin!
    assert GLOBAL.size == 3
    GLOBAL.slice!(0, 3)
  end

end
